@@ -24,6 +24,7 @@ THE SOFTWARE.  */
 
 #include <ctype.h>
 #include <stdlib.h>
+#include <strings.h>
 #include <errno.h>
 #include <math.h>
 #include <wordexp.h>
@@ -34,6 +35,10 @@ THE SOFTWARE.  */
 #include <htslib/hts_defs.h>
 #include <htslib/vcfutils.h>
 
+#ifndef __FUNCTION__
+#  define __FUNCTION__ __func__
+#endif
+
 uint64_t bcf_double_missing    = 0x7ff0000000000001;
 uint64_t bcf_double_vector_end = 0x7ff0000000000002;
 static inline void bcf_double_set(double *ptr, uint64_t value)
@@ -693,6 +698,40 @@ static void filters_set_alt_string(filter_t *flt, bcf1_t *line, token_t *tok)
     tok->values[0] = str.m;
     tok->str_value = str.s;
 }
+static void filters_set_nmissing(filter_t *flt, bcf1_t *line, token_t *tok)
+{
+    bcf_unpack(line, BCF_UN_FMT);
+    if ( !line->n_sample )
+    {
+        tok->nvalues = 1;
+        tok->values[0] = 0;
+        return;
+    }
+
+    int i,igt = bcf_hdr_id2int(flt->hdr, BCF_DT_ID, "GT");
+    bcf_fmt_t *fmt = NULL;
+    for (i=0; i<line->n_fmt; i++)
+        if ( line->d.fmt[i].id==igt ) { fmt = &line->d.fmt[i]; break; }
+    if ( !fmt )
+    {
+        tok->nvalues = 0;
+        return;
+    }
+    if ( fmt->type!=BCF_BT_INT8 ) error("TODO: the GT fmt_type is not int8\n");
+
+    int j,nmissing = 0;
+    for (i=0; i<line->n_sample; i++)
+    {
+        int8_t *ptr = (int8_t*) (fmt->p + i*fmt->size);
+        for (j=0; j<fmt->n; j++)
+        {
+            if ( ptr[j]==bcf_int8_vector_end ) break;
+            if ( ptr[j]==bcf_gt_missing ) { nmissing++; break; }
+        }
+    }
+    tok->nvalues = 1;
+    tok->values[0] = tok->tag[0]=='N' ? nmissing : (double)nmissing / line->n_sample;
+}
 static void filters_set_nalt(filter_t *flt, bcf1_t *line, token_t *tok)
 {
     tok->nvalues = 1;
@@ -827,6 +866,7 @@ static void set_strlen(filter_t *flt, bcf1_t *line, token_t *tok)
         {
             char *se = ss;
             while ( *se && *se!=',' ) se++;
+            hts_expand(double, i+1, tok->mvalues, tok->values);
             if ( !*se ) tok->values[i] = strlen(ss);
             else
             {
@@ -1298,6 +1338,18 @@ static int filters_init1(filter_t *filter, char *str, int len, token_t *tok)
             tok->threshold = bcf_hdr_nsamples(filter->hdr);
             return 0;
         }
+        else if ( !strncasecmp(str,"N_MISSING",len) )
+        {
+            tok->setter = &filters_set_nmissing;
+            tok->tag = strdup("N_MISSING");
+            return 0;
+        }
+        else if ( !strncasecmp(str,"F_MISSING",len) )
+        {
+            tok->setter = &filters_set_nmissing;
+            tok->tag = strdup("F_MISSING");
+            return 0;
+        }
     }
 
     // does it have array subscript?
@@ -1610,6 +1662,7 @@ filter_t *filter_init(bcf_hdr_t *hdr, const char *str)
             else if ( !strcasecmp(out[ival].key,"indel") || !strcasecmp(out[ival].key,"indels") ) { out[ival].threshold = VCF_INDEL<<1; out[ival].is_str = 0; }
             else if ( !strcasecmp(out[ival].key,"mnp") || !strcasecmp(out[ival].key,"mnps") ) { out[ival].threshold = VCF_MNP<<1; out[ival].is_str = 0; }
             else if ( !strcasecmp(out[ival].key,"other") ) { out[ival].threshold = VCF_OTHER<<1; out[ival].is_str = 0; }
+            else if ( !strcasecmp(out[ival].key,"bnd") ) { out[ival].threshold = VCF_BND<<1; out[ival].is_str = 0; }
             else if ( !strcasecmp(out[ival].key,"ref") ) { out[ival].threshold = 1; out[ival].is_str = 0; }
             else error("The type \"%s\" not recognised: %s\n", out[ival].key, filter->str);
             if ( out[itok].tok_type==TOK_LIKE || out[itok].tok_type==TOK_NLIKE ) out[itok].comparator = filters_cmp_bit_and;
